@@ -1,12 +1,13 @@
 #!/usr/bin/perl
 package Term::ExtendedColor::Xresources;
 use strict;
+use warnings;
 
 BEGIN {
   use Exporter;
   use vars qw($VERSION @ISA @EXPORT_OK);
 
-  $VERSION = '0.075';
+  $VERSION = '0.078';
   @ISA     = qw(Exporter);
   @EXPORT_OK = qw(
     set_xterm_color
@@ -21,7 +22,10 @@ BEGIN {
 use Carp qw(croak);
 use Term::ReadKey;
 
-*get_xterm_color = *get_xterm_colors;
+{
+  no warnings;
+  *get_xterm_color = *get_xterm_colors;
+}
 
 sub get_xterm_colors {
   my $arg = shift;
